#!/usr/bin/env python

#
# Usage: python em01b-var-2-comp-idx.py HOST [PORT]
#
# Sends "/status.xml" request to websensor and computes *IDX macro values for
# use in websensor-em01b-var-2.db.
#
# Example:
# $ python em01b-var-2-comp-idx.py localhost
#

import collections
import os
import socket
import sys

DEFAULT_PORT = 80
REQUEST = "GET /status.xml HTTP/1.0\r\n\r\n"
RECEIVE_BUFFER_SIZE = 512
INDEX_OFFSET = -10

def main():
  (host, port) = getCommandLineArgs()
  s = createConnectedSocket(host, port)
  s.send(REQUEST)
  print >> sys.stderr, "> \"%s\"" % REQUEST.encode("string_escape")
  sys.stderr.flush()
  response = s.recv(RECEIVE_BUFFER_SIZE)
  print >> sys.stderr, "< \"%s\"" % response.encode("string_escape")
  sys.stderr.flush()
  s.close()
  macros = collections.OrderedDict([
    ("TIDX", "<tm0>"),
    ("HIDX", "<hu0>"),
    ("IIDX", "<il0>"),
    ("THIDX", "<thm>"),
    ("TUIDX", "<tun0>")
  ])
  for k, v in macros.iteritems():
    idx = response.find(v)
    if idx != -1:
      print >> sys.stderr, "%s=%d" % (k, idx + INDEX_OFFSET)
    else:
      print >> sys.stderr, 'error: couldn\'t find "%s" in response' % v
      sys.exit(1)

def createConnectedSocket(host, port):
  s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
  s.connect((host, port))
  return s

def getCommandLineArgs():
  if len(sys.argv) <= 1:
    print >> sys.stderr, "error: expected HOST argument"
    sys.exit(1)
  host = sys.argv[1]
  port = DEFAULT_PORT
  if len(sys.argv) > 2: port = int(sys.argv[2])
  return (host, port)

if __name__ == "__main__": main()
